@@ -1,9 +1,9 @@
-#include <sensor_msgs/Image.h>
-
 #include <depthai_bridge/ImageConverter.hpp>
-#include <opencv2/opencv.hpp>
 
-#include "ros/ros.h"
+#include "opencv2/core/mat.hpp"
+#include "opencv2/highgui.hpp"
+#include "ros/node_handle.h"
+#include "sensor_msgs/Image.h"
 
 // Inludes common necessary includes for development using depthai library
 
